@@ -14,9 +14,11 @@ tags_to_test = (
     "image",
     "image-missing_caption",
     "image-no_caption",
+    "image-mime_type",
     "featuredimage",
     "featuredimage-missing_caption",
     "featuredimage-no_caption",
+    "featuredimage-mime_type",
     "horizontal_rule",
     "embed",
     "embed-missing_caption",
