@@ -3,8 +3,11 @@ import json
 from html import escape as e
 from typing import Dict
 from inspect import isclass
+from urllib.parse import urlparse
+from .image import url2mime
 
-__version__ = '0.7.0'
+
+__version__ = '0.7.5'
 
 renderers: Dict = {}
 
@@ -17,6 +20,7 @@ class BaseNode:
     """
     type = "prose-mirror_content-type"
     wrap_tag: str = ""
+    css_class: str = ""
 
     def is_renderable(self, node):
         """
@@ -29,8 +33,9 @@ class BaseNode:
         out = ''
         if self.is_renderable(in_data):
             out = self.inner_render(in_data)
+            css_class_s = f' class="{self.css_class}"' if self.css_class else ''
             if self.wrap_tag:
-                out = f"<{self.wrap_tag}>{out}</{self.wrap_tag}>"
+                out = f"<{self.wrap_tag}{css_class_s}>{out}</{self.wrap_tag}>"
         return out
 
     def inner_render(self, node) -> str:
@@ -53,6 +58,13 @@ class BaseContainer(BaseNode):
         return out
 
 
+class config:
+    """
+    Config class to store constans which are used by the othe nodes.
+    """
+    DOMAIN = "python.org"
+
+
 class Text(BaseNode):
     type = "text"
     mark_tags = {"bold": "strong", "italic": "em", "link": "a"}
@@ -65,6 +77,11 @@ class Text(BaseNode):
                 tag = self.mark_tags.get(mark.get("type"))
                 attrs = mark.get("attrs")
                 if attrs:
+                    if tag == "a":
+                        url = attrs.get("href") or ""
+                        if not is_trusted_link(url):
+                            attrs["target"] = "_blank"
+                            attrs["rel"] = "noopener nofollow"
                     attrs_s = " ".join(f'{k}="{e(v)}"' for k, v in attrs.items())
                     text = f"<{tag} {attrs_s}>{text}</{tag}>"
                 else:
@@ -89,21 +106,25 @@ class Image(BaseNode):
 
     def is_renderable(self, node):
         attrs = node.get("attrs", {})
-        return bool(attrs.get('src', '').strip())
-
+        src = attrs.get("src", "")
+        return src and bool(
+            src.get('image', '').strip() or src.get('fallback', '').strip()
+        )
 
     def inner_render(self, node) -> str:
-        special_attrs_map = {'caption': 'figcaption'}
-        attrs = node.get("attrs", {})
-        attrs_s = " ".join(f'{k}="{v}"'
-                           for k, v in attrs.items()
-                           if k not in special_attrs_map and v.strip()
-                           )
-        html = f"<img {attrs_s}>"
+        attrs = node["attrs"]
+        alt = attrs.get('alt', '').strip()
         caption = attrs.get('caption', '').strip()
+        image_url = attrs['src']['image']
+        fallback_url = attrs['src']['fallback']
+        image_type = url2mime(image_url)
+        fallback_type = url2mime(fallback_url)
+        image_src = f'<img src="{fallback_url}"/>'
+        if alt:
+            image_src = f'<img src="{fallback_url}" alt="{e(alt)}"/>'
+        html = f'<picture><source srcset="{image_url}" type="{image_type}"/><source srcset="{fallback_url}" type="{fallback_type}"/>{image_src}</picture>'  # noqa: E501
         if caption:
-            tag = special_attrs_map['caption']
-            html += f"<{tag}>{e(caption)}</{tag}>"
+            html = html + f'<figcaption>{e(caption)}</figcaption>'
         return html
 
 
@@ -184,6 +205,16 @@ def convert_any(in_data):
     return renderer.render(in_data)
 
 
+def is_trusted_link(url):
+    """
+    Check if the domain is the same as in the config.
+    """
+    link = urlparse(url)
+    # Getting the domain of the link
+    link = link.netloc
+    return link.endswith(config.DOMAIN)
+
+
 def to_html(s):
     in_data = s if isinstance(s, dict) else json.loads(s)
     return convert_any(in_data)
